@@ -1,7 +1,7 @@
 #' Quoting operators
 #'
 #' These functions make it easy to quote each individual element and are useful
-#' in conjunction with `glue_collapse()`.
+#' in conjunction with [glue_collapse()].
 #' @param x A character to quote.
 #' @name quoting
 #' @export
@@ -9,17 +9,17 @@
 #' x <- 1:5
 #' glue('Values of x: {glue_collapse(backtick(x), sep = ", ", last = " and ")}')
 single_quote <- function(x) {
-  encodeString(x, quote = "'")
+  encodeString(x, quote = "'", na.encode = FALSE)
 }
 
 #' @rdname quoting
 #' @export
 double_quote <- function(x) {
-  encodeString(x, quote = '"')
+  encodeString(x, quote = '"', na.encode = FALSE)
 }
 
 #' @rdname quoting
 #' @export
 backtick <- function(x) {
-  encodeString(x, quote = "`")
+  encodeString(x, quote = "`", na.encode = FALSE)
 }
